'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Picker = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _components = require('../components');

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _semanticUiReact = require('semantic-ui-react');

var _utils = require('../utils.js');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Picker = function (_React$Component) {
  _inherits(Picker, _React$Component);

  function Picker(props) {
    _classCallCheck(this, Picker);

    var _this = _possibleConstructorReturn(this, (Picker.__proto__ || Object.getPrototypeOf(Picker)).call(this, props));

    _this.componentDidUpdate = function (prevProps, prevState) {
      var _this$state = _this.state,
          activeDate = _this$state.activeDate,
          activeHour = _this$state.activeHour,
          activeMinute = _this$state.activeMinute,
          datesRange = _this$state.datesRange;
      var _this$props = _this.props,
          onDateChange = _this$props.onDateChange,
          onTimeChange = _this$props.onTimeChange,
          onDatesRangeChange = _this$props.onDatesRangeChange;

      var dateChanged = activeDate && activeDate.isSame && !activeDate.isSame(prevState.activeDate);
      var timeChanged = activeHour && activeMinute && (activeHour !== prevState.activeHour || activeMinute !== prevState.activeMinute);
      var datesRangeChanged = datesRange.start && datesRange.end && (!datesRange.start.isSame(prevState.datesRange.start) || !datesRange.end.isSame(prevState.datesRange.end));

      if (dateChanged) {
        onDateChange(activeDate);
      }
      if (timeChanged) {
        onTimeChange(activeHour + ':' + activeMinute);
      }
      if (datesRangeChanged) {
        onDatesRangeChange(datesRange);
      }
    };

    _this.setDatesRange = function (clickedDate) {
      _this.setState(function (_ref) {
        var datesRange = _ref.datesRange;

        if (datesRange.start && datesRange.end) {
          return {
            datesRange: { start: null, end: null }
          };
        }
        if (datesRange.start) {
          if (datesRange.start.isAfter(clickedDate)) {
            return {
              datesRange: { start: null, end: null }
            };
          }
          return {
            datesRange: { start: datesRange.start, end: clickedDate }
          };
        }
        return {
          datesRange: { start: clickedDate, end: datesRange.end }
        };
      });
    };

    _this.onDateClick = function (clickedDate) {
      var pickDatesRange = _this.props.pickDatesRange;


      if (pickDatesRange) {
        _this.setDatesRange(clickedDate);
      } else {
        _this.setState({
          activeDate: clickedDate
        });
      }
    };

    _this.onHourClick = function (clickedHour) {
      _this.setState({
        activeHour: clickedHour
      });
    };

    _this.onMinuteClick = function (clickedMinute) {
      _this.setState({
        activeMinute: clickedMinute
      });
    };

    _this.onNextBtnClick = function (_ref2) {
      var day = _ref2.day;

      if (day) {
        _this.setState(function (_ref3) {
          var activeDate = _ref3.activeDate;

          var nextDay = activeDate.clone();
          nextDay.add(1, 'd');
          return { activeDate: nextDay };
        });
      } else {
        _this.setState(function (_ref4) {
          var showedMonth = _ref4.showedMonth;

          var nextMonth = showedMonth.clone();
          nextMonth.add(1, 'M');
          return { showedMonth: nextMonth };
        });
      }
    };

    _this.onPrevBtnClick = function (_ref5) {
      var day = _ref5.day;

      if (day) {
        _this.setState(function (_ref6) {
          var activeDate = _ref6.activeDate;

          var prevDay = activeDate.clone();
          prevDay.add(-1, 'd');
          return { activeDate: prevDay };
        });
      } else {
        _this.setState(function (_ref7) {
          var showedMonth = _ref7.showedMonth;

          var prevMonth = showedMonth.clone();
          prevMonth.add(-1, 'M');
          return { showedMonth: prevMonth };
        });
      }
    };

    _this.getActiveDate = function () {
      return _this.state.activeDate || (0, _moment2.default)();
    };

    _this.getDateTimePicker = function () {
      var _this$state2 = _this.state,
          activeDate = _this$state2.activeDate,
          activeHour = _this$state2.activeHour,
          activeMinute = _this$state2.activeMinute,
          showedMonth = _this$state2.showedMonth;

      var headerWidth = activeHour ? '3' : activeDate ? '4' : '7';
      if (!activeDate) {
        return _react2.default.createElement(
          _react2.default.Fragment,
          null,
          _react2.default.createElement(_components.DateTimePickerHeader, {
            onNextBtnClick: _this.onNextBtnClick,
            onPrevBtnClick: _this.onPrevBtnClick,
            showedDate: showedMonth,
            showDate: false,
            showWeeks: true,
            width: '7' }),
          _react2.default.createElement(_components.DatePickerComponent, {
            onDateClick: _this.onDateClick,
            activeDate: _this.getActiveDate(),
            showedMonth: showedMonth })
        );
      }
      return _react2.default.createElement(
        _react2.default.Fragment,
        null,
        _react2.default.createElement(_components.DateTimePickerHeader, {
          onNextBtnClick: _this.onNextBtnClick.bind(null, { day: true }),
          onPrevBtnClick: _this.onPrevBtnClick.bind(null, { day: true }),
          showedDate: activeDate,
          showDate: true,
          showWeeks: false,
          width: headerWidth }),
        _react2.default.createElement(_components.TimePickerComponent, {
          activeHour: activeHour,
          activeMinute: activeMinute,
          onHourClick: _this.onHourClick,
          onMinuteClick: _this.onMinuteClick })
      );
    };

    _this.state = {
      activeDate: null,
      showedMonth: (0, _moment2.default)(),
      activeHour: '',
      activeMinute: '',
      datesRange: { start: null, end: null }
    };
    return _this;
  }

  _createClass(Picker, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          pickDate = _props.pickDate,
          pickTime = _props.pickTime,
          pickDateTime = _props.pickDateTime,
          pickDatesRange = _props.pickDatesRange;

      var rest = (0, _utils.getUnhandledProps)(Picker, this.props);

      if (pickDate) {
        return _react2.default.createElement(
          _semanticUiReact.Table,
          _extends({}, rest, {
            unstackable: true,
            celled: true,
            textAlign: 'center' }),
          _react2.default.createElement(_components.DateTimePickerHeader, {
            onNextBtnClick: this.onNextBtnClick,
            onPrevBtnClick: this.onPrevBtnClick,
            showedDate: this.state.showedMonth,
            showDate: false,
            showWeeks: true,
            width: '7' }),
          _react2.default.createElement(_components.DatePickerComponent, {
            onDateClick: this.onDateClick,
            activeDate: this.getActiveDate(),
            showedMonth: this.state.showedMonth })
        );
      }
      if (pickTime) {
        return _react2.default.createElement(
          _semanticUiReact.Table,
          _extends({}, rest, {
            unstackable: true,
            celled: true,
            textAlign: 'center' }),
          _react2.default.createElement(_components.TimePickerComponent, {
            activeHour: this.state.activeHour,
            activeMinute: this.state.activeMinute,
            onHourClick: this.onHourClick,
            onMinuteClick: this.onMinuteClick })
        );
      }
      if (pickDateTime) {
        return _react2.default.createElement(
          _semanticUiReact.Table,
          _extends({}, rest, {
            unstackable: true,
            celled: true,
            textAlign: 'center' }),
          this.getDateTimePicker()
        );
      }
      if (pickDatesRange) {
        return _react2.default.createElement(
          _semanticUiReact.Table,
          _extends({}, rest, {
            unstackable: true,
            celled: true,
            textAlign: 'center' }),
          _react2.default.createElement(_components.DateTimePickerHeader, {
            onNextBtnClick: this.onNextBtnClick,
            onPrevBtnClick: this.onPrevBtnClick,
            showedDate: this.state.showedMonth,
            showedRange: this.state.datesRange,
            showDate: false,
            showWeeks: true,
            width: '7' }),
          _react2.default.createElement(_components.DatePickerComponent, {
            datesRange: this.state.datesRange,
            onDateClick: this.onDateClick,
            showedMonth: this.state.showedMonth })
        );
      }
    }
  }]);

  return Picker;
}(_react2.default.Component);

Picker.handledProps = ['onDateChange', 'onDatesRangeChange', 'onTimeChange', 'pickDate', 'pickDateTime', 'pickDatesRange', 'pickTime'];


Picker.propTypes = {
  pickDate: _propTypes2.default.bool,
  pickTime: _propTypes2.default.bool,
  pickDateTime: _propTypes2.default.bool,
  pickDatesRange: _propTypes2.default.bool,
  /** (newDate) => {} 
   * @param {moment} newDate
  */
  onDateChange: _propTypes2.default.func,
  /** (newTime) => {}
   * @param {string} newTime hh:mm
   */
  onTimeChange: _propTypes2.default.func,
  /** (newDatesRange) => {}
   * @param {{start: moment, end: moment}} newDatesRange
  */
  onDatesRangeChange: _propTypes2.default.func
};

Picker.defaultProps = {
  onDateChange: function onDateChange() {},
  onTimeChange: function onTimeChange() {},
  onDatesRangeChange: function onDatesRangeChange() {}
};

exports.default = Picker;
exports.Picker = Picker;